@@ -1,6 +1,6 @@
 from netbox.forms import NetBoxModelForm
 from pyrsistent import v
-from .models import Aduser, RiskRelation, RiskAssignment
+from .models import Risk, RiskRelation#, RiskAssignment
 from utilities.forms import (
     BootstrapMixin, DynamicModelChoiceField)
 from django import forms
@@ -8,7 +8,7 @@ from django import forms
 
 class RiskForm(NetBoxModelForm):
     class Meta:
-        model = Aduser
+        model = Risk
         fields = ('name',
                   'sAMAccountName',
                   'status',
@@ -22,19 +22,5 @@ class RiskForm(NetBoxModelForm):
 class RiskRelationForm(NetBoxModelForm):
     class Meta:
         model = RiskRelation
-        fields = ('name', 'description')
+        fields = ('name', 'CN', 'DistinguishedName', 'ad_guid', 'ad_description', 'description')
 
-
-class RiskAssignmentForm(BootstrapMixin, forms.ModelForm):
-    risk = DynamicModelChoiceField(
-        queryset=Aduser.objects.all()
-    )
-    relation = DynamicModelChoiceField(
-        queryset=RiskRelation.objects.all()
-    )
-
-    class Meta:
-        model = RiskAssignment
-        fields = (
-            'risk', 'relation',
-        )
